@@ -2,4 +2,6 @@
 # -*- coding: utf-8 -*- 
 # @Time : 2020/5/18 13:51
 # @Author : yangpingyan@gmail.com
-name = 'ypyapi_4'
\ No newline at end of file
+from .chrome_api import *
+
+__VERSION__ = '0.0.9'
